@@ -1,20 +1,19 @@
 /*
- *  seccure  -  Copyright 2009 B. Poettering
+ *  seccure  -  Copyright 2014 B. Poettering
  *
  *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of the
- *  License, or (at your option) any later version.
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 3 of
+ *  the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- *  02111-1307 USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
 /* 
@@ -72,11 +71,11 @@ struct aes256ctr* aes256ctr_init(const char *key)
   return NULL;
 }
 
-void aes256ctr_enc(struct aes256ctr *ac, char *buf, int len)
+void aes256ctr_enc(struct aes256ctr *ac, char *buf, size_t len)
 {
   gcry_error_t err;
-  int full_blocks;
-
+  size_t full_blocks;
+  
   for(; len && (ac->idx < CIPHER_BLOCK_SIZE); len--)
     *buf++ ^= ac->buf[ac->idx++];
 
@@ -104,7 +103,7 @@ void aes256ctr_done(struct aes256ctr *ac)
   gcry_free(ac);
 }
 
-int hmacsha256_init(gcry_md_hd_t *mh, const char *key, int len)
+int hmacsha256_init(gcry_md_hd_t *mh, const char *key, size_t len)
 {
   gcry_error_t err;
 
@@ -117,7 +116,7 @@ int hmacsha256_init(gcry_md_hd_t *mh, const char *key, int len)
   return ! gcry_err_code(err);
 }
 
-void aes256cprng_fillbuf(struct aes256cprng *cprng, char *buf, int len)
+void aes256cprng_fillbuf(struct aes256cprng *cprng, char *buf, size_t len)
 {
   memset(buf, 0, len);
   aes256ctr_enc(cprng, buf, len);
