@@ -1,20 +1,19 @@
 /*
- *  seccure  -  Copyright 2009 B. Poettering
+ *  seccure  -  Copyright 2014 B. Poettering
  *
  *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of the
- *  License, or (at your option) any later version.
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 3 of
+ *  the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- *  02111-1307 USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
 /* 
@@ -40,17 +39,26 @@
 
 #include "ecc.h"
 
+#define MAX_PK_LEN_BIN 66
+#define MAX_PK_LEN_COMPACT 81
+#define MAX_SIG_LEN_BIN 131
+#define MAX_SIG_LEN_COMPACT 161
+#define MAX_DH_LEN_BIN 32
+#define MAX_DH_LEN_COMPACT 40
+#define MAX_ELEM_LEN_BIN 66
+#define MAX_ORDER_LEN_BIN 66
+
 struct curve_params {
   const char *name;
   struct domain_params dp;
-  int pk_len_bin, pk_len_compact;
-  int sig_len_bin, sig_len_compact;
-  int dh_len_bin, dh_len_compact;
-  int elem_len_bin, order_len_bin;
+  size_t pk_len_bin, pk_len_compact;
+  size_t sig_len_bin, sig_len_compact;
+  size_t dh_len_bin, dh_len_compact;
+  size_t elem_len_bin, order_len_bin;
 };
 
 struct curve_params* curve_by_name(const char *name);
-struct curve_params* curve_by_pk_len_compact(int len);
+struct curve_params* curve_by_pk_len_compact(size_t len);
 void curve_release(struct curve_params *cp);
 
 #endif /* INC_CURVES_H */
