@@ -1,20 +1,19 @@
 /*
- *  seccure  -  Copyright 2009 B. Poettering
+ *  seccure  -  Copyright 2014 B. Poettering
  *
  *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of the
- *  License, or (at your option) any later version.
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 3 of
+ *  the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- *  02111-1307 USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
 /* 
@@ -48,7 +47,7 @@
 
 /******************************************************************************/
 
-gcry_mpi_t buf_to_exponent(const char *buf, int buflen,
+gcry_mpi_t buf_to_exponent(const char *buf, size_t buflen,
 			   const struct curve_params *cp)
 {
   gcry_mpi_t a, b;
@@ -64,7 +63,7 @@ gcry_mpi_t buf_to_exponent(const char *buf, int buflen,
 
 gcry_mpi_t hash_to_exponent(const char *hash, const struct curve_params *cp)
 {
-  int len = cp->order_len_bin;
+  size_t len = cp->order_len_bin;
   struct aes256cprng *cprng;
   gcry_mpi_t a;
   char *buf;
@@ -95,7 +94,7 @@ void compress_to_string(char *buf, enum disp_format df,
 			const struct affine_point *P, 
 			const struct curve_params *cp)
 {
-  int outlen = (df == DF_COMPACT) ? cp->pk_len_compact : cp->pk_len_bin;
+  size_t outlen = (df == DF_COMPACT) ? cp->pk_len_compact : cp->pk_len_bin;
   if (point_compress(P)) {
     gcry_mpi_t x;
     x = gcry_mpi_snew(0);
@@ -111,7 +110,7 @@ int decompress_from_string(struct affine_point *P, const char *buf,
 			   enum disp_format df, const struct curve_params *cp)
 {
   gcry_mpi_t x;
-  int inlen = (df == DF_COMPACT) ? cp->pk_len_compact : cp->pk_len_bin;
+  size_t inlen = (df == DF_COMPACT) ? cp->pk_len_compact : cp->pk_len_bin;
   int res;
   assert(! (df == DF_COMPACT && strlen(buf) != inlen));
   if ((res = deserialize_mpi(&x, df, buf, inlen))) {
@@ -133,7 +132,7 @@ static struct aes256cprng*
 ecdsa_cprng_init(const char *msg, const gcry_mpi_t d,
 		 const struct curve_params *cp)
 {
-  int len = cp->order_len_bin;
+  size_t len = cp->order_len_bin;
   struct aes256cprng *cprng;
   gcry_md_hd_t mh;
   char *buf;
@@ -152,7 +151,7 @@ static gcry_mpi_t
 ecdsa_cprng_get_exponent(struct aes256cprng *cprng,
 			 const struct curve_params *cp)
 {
-  int len = cp->order_len_bin;
+  size_t len = cp->order_len_bin;
   gcry_mpi_t a;
   char *buf;
   assert((buf = gcry_malloc_secure(len)));
@@ -251,7 +250,7 @@ int ECDSA_verify(const char *msg, const struct affine_point *Q,
 
 /* Algorithms 4.42 and 4.43 in the "Guide to Elliptic Curve Cryptography"     */
 static void ECIES_KDF(char *key, const gcry_mpi_t Zx, 
-		      const struct affine_point *R, int elemlen)
+		      const struct affine_point *R, size_t elemlen)
 {
   char *buf;
   assert((buf = gcry_malloc_secure(3 * elemlen)));
@@ -262,8 +261,8 @@ static void ECIES_KDF(char *key, const gcry_mpi_t Zx,
   gcry_free(buf);
 }
 
-struct affine_point ECIES_encryption(char *key, const struct affine_point *Q, 
-				     const struct curve_params *cp)
+struct affine_point ECIES_encapsulation(char *key, const struct affine_point *Q, 
+                                        const struct curve_params *cp)
 {
   struct affine_point Z, R;
   gcry_mpi_t k;
@@ -283,8 +282,8 @@ struct affine_point ECIES_encryption(char *key, const struct affine_point *Q,
   return R;
 }
 
-int ECIES_decryption(char *key, const struct affine_point *R,
-		     const gcry_mpi_t d, const struct curve_params *cp)
+int ECIES_decapsulation(char *key, const struct affine_point *R,
+                        const gcry_mpi_t d, const struct curve_params *cp)
 {
   struct affine_point Z;
   gcry_mpi_t e;
@@ -303,7 +302,7 @@ int ECIES_decryption(char *key, const struct affine_point *R,
 
 /******************************************************************************/
 
-static void DH_KDF(char *key, const struct affine_point *P, int elemlen)
+static void DH_KDF(char *key, const struct affine_point *P, size_t elemlen)
 {
   char *buf;
   assert((buf = gcry_malloc_secure(2 * elemlen)));
