@@ -1,20 +1,19 @@
 /*
- *  seccure  -  Copyright 2009 B. Poettering
+ *  seccure  -  Copyright 2014 B. Poettering
  *
  *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of the
- *  License, or (at your option) any later version.
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 3 of
+ *  the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- *  02111-1307 USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
 /* 
@@ -41,7 +40,7 @@
 #include "curves.h"
 #include "serialize.h"
 
-gcry_mpi_t buf_to_exponent(const char *buf, int buflen,
+gcry_mpi_t buf_to_exponent(const char *buf, size_t buflen,
 			   const struct curve_params *cp);
 gcry_mpi_t hash_to_exponent(const char *hash, const struct curve_params *cp);
 gcry_mpi_t get_random_exponent(const struct curve_params *cp);
@@ -57,10 +56,10 @@ gcry_mpi_t ECDSA_sign(const char *msg, const gcry_mpi_t d,
 int ECDSA_verify(const char *msg, const struct affine_point *Q, 
 		 const gcry_mpi_t sig, const struct curve_params *cp);
 
-struct affine_point ECIES_encryption(char *key, const struct affine_point *Q, 
-				     const struct curve_params *cp);
-int ECIES_decryption(char *key, const struct affine_point *R, 
-		     const gcry_mpi_t d, const struct curve_params *cp);
+struct affine_point ECIES_encapsulation(char *key, const struct affine_point *Q, 
+                                        const struct curve_params *cp);
+int ECIES_decapsulation(char *key, const struct affine_point *R, 
+                        const gcry_mpi_t d, const struct curve_params *cp);
 
 gcry_mpi_t DH_step1(struct affine_point *A, const struct curve_params *cp);
 int DH_step2(char *key, const struct affine_point *B, const gcry_mpi_t exp, 
