@@ -1,20 +1,19 @@
 /*
- *  seccure  -  Copyright 2009 B. Poettering
+ *  seccure  -  Copyright 2014 B. Poettering
  *
  *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of the
- *  License, or (at your option) any later version.
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 3 of
+ *  the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- *  02111-1307 USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
 /* 
@@ -52,9 +51,9 @@ const char compact_digits[COMPACT_DIGITS_COUNT] = {
   'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 
   'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', '{', '|', '}', '~' };
 
-int get_serialization_len(const gcry_mpi_t x, enum disp_format df)
+size_t get_serialization_len(const gcry_mpi_t x, enum disp_format df)
 {
-  int res;
+  size_t res;
   switch(df) {
   case DF_BIN:
     res = (gcry_mpi_get_nbits(x) + 7) / 8;
@@ -75,12 +74,12 @@ int get_serialization_len(const gcry_mpi_t x, enum disp_format df)
   return res;
 }
 
-void serialize_mpi(char *outbuf, int outlen, enum disp_format df, 
+void serialize_mpi(char *outbuf, size_t outlen, enum disp_format df, 
 		   const gcry_mpi_t x)
 {
   switch(df) {
   case DF_BIN: do {
-      int len = (gcry_mpi_get_nbits(x) + 7) / 8;
+      size_t len = (gcry_mpi_get_nbits(x) + 7) / 8;
       assert(len <= outlen);
       memset(outbuf, 0, outlen - len);
       gcry_mpi_print(GCRYMPI_FMT_USG, (unsigned char*)outbuf + (outlen - len), 
@@ -112,7 +111,7 @@ void serialize_mpi(char *outbuf, int outlen, enum disp_format df,
 }
 
 int deserialize_mpi(gcry_mpi_t *x, enum disp_format df, const char *buf, 
-		    int inlen)
+		    size_t inlen)
 {
   switch(df) {
   case DF_BIN:
@@ -121,7 +120,7 @@ int deserialize_mpi(gcry_mpi_t *x, enum disp_format df, const char *buf,
     break;
   case DF_COMPACT: do {
       char *d;
-      int i;
+      size_t i;
       *x = gcry_mpi_snew(0);
       for(i = 0; i < inlen; i++) {
 	if (! (d = memchr(compact_digits, buf[i], COMPACT_DIGITS_COUNT))) {
