@@ -1,20 +1,19 @@
 /*
- *  seccure  -  Copyright 2009 B. Poettering
+ *  seccure  -  Copyright 2014 B. Poettering
  *
  *  This program is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU General Public License as
- *  published by the Free Software Foundation; either version 2 of the
- *  License, or (at your option) any later version.
+ *  modify it under the terms of the GNU Lesser General Public License
+ *  as published by the Free Software Foundation; either version 3 of
+ *  the License, or (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  General Public License for more details.
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- *  02111-1307 USA
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program. If not, see
+ *  <http://www.gnu.org/licenses/>.
  */
 
 /* 
@@ -45,10 +44,10 @@ enum disp_format { DF_BIN, DF_COMPACT };
 #define COMPACT_DIGITS_COUNT 90
 extern const char compact_digits[];
 
-int get_serialization_len(const gcry_mpi_t x, enum disp_format df);
-void serialize_mpi(char *outbuf, int outlen, enum disp_format df, 
+size_t get_serialization_len(const gcry_mpi_t x, enum disp_format df);
+void serialize_mpi(char *outbuf, size_t outlen, enum disp_format df, 
 		   const gcry_mpi_t x);
 int deserialize_mpi(gcry_mpi_t *x, enum disp_format ds, const char *buf, 
-		    int inlen);
+		    size_t inlen);
 
 #endif /* INC_SERIALIZE_H */
